<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'プラグインを有効にする',
	'affichage' => '表示',
	'aide_non_disponible' => '現在の言語の設定では、このオンラインヘルプはまだご利用になれません。',
	'annuler_recherche' => '検索を取り消す',
	'auteur' => '著者：',
	'avis_acces_interdit' => 'アクセス禁止',
	'avis_acces_interdit_prive' => '<b>@exec@</b>ページにアクセス禁止。',
	'avis_article_modifie' => 'ご注意ください。@nom_auteur_modif@が@date_diff@分前にこの記事を編集しました。',
	'avis_aucun_resultat' => '当たるデータがありません。',
	'avis_base_inaccessible' => 'データーベース@base@に接続出来ません。',
	'avis_chemin_invalide_1' => 'パスが有効ではないみたいです。',
	'avis_chemin_invalide_2' => '前のページに戻って、入力された情報を確認してください。',
	'avis_connexion_echec_1' => 'SQLサーバーへの接続は失敗しました。',
	'avis_connexion_echec_2' => '前のページに戻って、入力された情報を確認してください。',
	'avis_connexion_echec_3' => '<b>注意</b>多くのサーバーには、データーベースにアクセス権を要求していただいた上でご利用になります。接続が出来なければ、アクセス権を確認してください。',
	'avis_connexion_erreur_creer_base' => 'データーベース作成は失敗です。',
	'avis_connexion_erreur_fichier_cle_manquant_1' => 'インストールは、ウェブマスターがキーとパスワードのバックアップをとって行う必要があります。', # MODIF
	'avis_connexion_erreur_fichier_cle_manquant_2' => 'インストールはウェブマスターがキーのバックアップをとって行う必要があります', # MODIF
	'avis_connexion_erreur_nom_base' => 'データーベース名には、文字、数字、およびハイフンのみ使ってください。',
	'avis_connexion_ldap_echec_1' => 'LDAPサーバへの接続は失敗しました。',
	'avis_connexion_ldap_echec_2' => '前のページに戻って、与えられている情報を確認してください。',
	'avis_connexion_ldap_echec_3' => 'ユーザのインポートのためにLDAPサポートを利用しないでください。', # MODIF
	'avis_deplacement_rubrique' => '注意！このセクションには、ニュースが@contient_breves@件入っています。移す場合
は、確認ボックスをチェックしてください。',
	'avis_erreur_connexion_mysql' => 'SQL接続のエラー',
	'avis_erreur_creation_compte' => 'アカウント初期化失敗',
	'avis_espace_interdit' => '<b>禁止エリア</b><div>SPIPが既にインストールされています。</div>',
	'avis_lecture_noms_bases_1' => 'インストールプログラムは、データベースの名を読むことが出来ませんでした。',
	'avis_lecture_noms_bases_2' => 'データベースが有効ではないか、データーベースのリストを表示する機能が有効されていないかのことです。これはプロバイダーのセキュリティ上の理由によります。',
	'avis_lecture_noms_bases_3' => '二つ目の選択において、あなたのＩＤを含むデータベースが利用可能のようです：',
	'avis_non_acces_page' => 'このページにはアクセス権を持っていません。',
	'avis_operation_echec' => '操作エラーです。',
	'avis_operation_impossible' => '操作不可です。',
	'avis_suppression_base' => '注意！データの削除は不可逆です。',

	// B
	'bouton_acces_ldap' => 'LDAPへのアクセスを追加する',
	'bouton_ajouter' => '追加する',
	'bouton_annuler' => '取り消す',
	'bouton_cache_activer' => 'キャッシュを再有効にする',
	'bouton_cache_desactiver' => '一時的にキャッシュを無効にする',
	'bouton_demande_publication' => 'この記事の公開を要求する',
	'bouton_desactive_tout' => '全部無効にする',
	'bouton_desinstaller' => 'アンインストールする',
	'bouton_effacer_tout' => '全部削除する',
	'bouton_envoyer_message' => '決定的なメッセージですから：送信する',
	'bouton_fermer' => '閉じる',
	'bouton_mettre_a_jour_base' => 'データベースを更新する',
	'bouton_modifier' => '修正',
	'bouton_radio_afficher' => '表示',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => '接続されている著者のリストに表示する', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'アナウンスを送信するアドレス：',
	'bouton_radio_envoi_liste_nouveautes' => '最新のニュースリストを送信する',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => '接続されている著者のリストに表示しない', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => '編集の発表を送信しない',
	'bouton_redirection' => 'リダイレクト',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'デフォルトにリセットする',
	'bouton_relancer_inscription' => '登録を再開する',
	'bouton_relancer_inscriptions' => '登録を再開する',
	'bouton_relancer_installation' => 'インストールを再開する',
	'bouton_reset_password' => '新規パスワードを生成して、メールで送信する',
	'bouton_suivant' => '次',
	'bouton_tenter_recuperation' => '修復を試みる',
	'bouton_test_proxy' => 'プロキシーをテストする',
	'bouton_vider_cache' => 'キャッシュを空白にする。',

	// C
	'cache_modifiable_webmestre' => 'この設定はウェブマスターが修正出来ます。', # MODIF
	'calendrier_synchro' => '<b>iCal</b>互換のカレンダーを使用する場合、当サイトの情報と同期することが出来ます',
	'config_activer_champs' => 'フィルドを有効にしてください。',
	'config_choix_base_sup' => 'データーベースを選んでください。',
	'config_erreur_base_sup' => 'SPIPは使用可能なデータベースのリストにアクセス出来ない。',
	'config_info_base_sup' => 'このSQLサーバーであれ、それ以外のサーバーであれ、SPIPを使用して他のデータベーを照会する必要がある場合は、このフォームを使用して設定してください。フィールドを空白のままにすると、主なデータベースへの接続設定が使用されます。',
	'config_info_base_sup_disponibles' => '補足のデータベースへ、クエリを送信できる：',
	'config_info_enregistree' => '新しい設定が保存されました。',
	'config_info_logos' => 'サイトの各オブシェクトは、独自のロゴと「オーバーロゴ」を持つことができます。',
	'config_info_logos_utiliser' => 'ロゴを使用する',
	'config_info_logos_utiliser_non' => 'ロゴを使用しない',
	'config_info_logos_utiliser_survol' => 'マウスオーバーロゴを使用する',
	'config_info_logos_utiliser_survol_non' => 'マウスオーバーロゴを使用しない',
	'config_info_redirection' => 'このオプションを有効にすると、仮想記事を作成できます。仮想記事とは、（必ずしもSPIPを使用されない）他のサイトに公開された記事へのリンクです。',
	'config_redirection' => '仮想記事',
	'config_titre_base_sup' => '新規データーベースを作成',
	'config_titre_base_sup_choix' => '補足のデータベースを選択してください。',
	'connexion_ldap' => '接続：',
	'creer_et_associer_un_auteur' => '新規著者を作成して関連付ける',

	// D
	'date_mot_heures' => '時',

	// E
	'ecran_connexion_couleur_principale' => '主なカラー',
	'ecran_connexion_image_fond' => '背景画像',
	'ecran_securite' => '+安全スクリーン@version@',
	'email' => 'メール',
	'email_2' => 'メール：',
	'en_savoir_plus' => '詳細について',
	'entree_adresse_annuaire' => 'ディレクトリのアドレス',
	'entree_adresse_email' => 'メールアドレス',
	'entree_adresse_email_2' => 'メールアドレス',
	'entree_base_donnee_1' => 'データベースアドレス',
	'entree_base_donnee_2' => '(このアドレスはサイトのアドレスと同じか、場合によって«localhost»の設定になるか、空白のままに残すかのことです。)',
	'entree_biographie' => '伝記を短く入力してください。',
	'entree_chemin_acces' => 'パスを<b>入力</b>：',
	'entree_cle_pgp' => 'あなたのPGPキー',
	'entree_cle_pgp_2' => 'PGPキー',
	'entree_contenu_rubrique' => '（セクションの内容を短く入力してください。）',
	'entree_identifiants_connexion' => 'あなたの接続ＩＤ…',
	'entree_identifiants_connexion_2' => 'あなたの接続ＩＤ…',
	'entree_informations_connexion_ldap' => 'このフォームには、システムまたはネットワーク管理者よりのLDAP接続情報を入力してください。', # MODIF
	'entree_infos_perso' => 'あなたは誰ですか？',
	'entree_infos_perso_2' => 'どんな著者ですか？',
	'entree_interieur_rubrique' => 'セクションの中に：',
	'entree_liens_sites' => '<b>ハイパーリンク</b>（訪問サイトの参照...）',
	'entree_login' => 'ログインＩＤ',
	'entree_login_connexion_1' => '接続するログインＩＤ',
	'entree_login_connexion_2' => 'FTPアクセスパスワードと一致になるか、空白のままに残るか、どちらかです。',
	'entree_mot_passe' => 'パスワード',
	'entree_mot_passe_1' => '接続パスワード',
	'entree_mot_passe_2' => 'FTPアクセスパスワードと一致になるか、空白のままに残るか、どちらかです。',
	'entree_nom_fichier' => 'ファイル名@texte_compresse@を記入してください：',
	'entree_nom_pseudo' => 'お名前／偽名入力',
	'entree_nom_pseudo_1' => '（お名前／偽名入力）',
	'entree_nom_pseudo_2' => '名前／偽名',
	'entree_nom_site' => '個人サイトの名前',
	'entree_nom_site_2' => 'サイト主のお名前',
	'entree_nouveau_passe' => '新規パスワード',
	'entree_passe_ldap' => 'パスワード',
	'entree_port_annuaire' => 'ディレクトリのポートナンバー',
	'entree_signature' => '署名',
	'entree_titre_obligatoire' => '［必須］<b>タイトル</b><br/>',
	'entree_url' => '個人サイトのURL',
	'entree_url_2' => 'サイトのURL',
	'erreur_connect_deja_existant' => 'この名のあるサーバーが既にあります。',
	'erreur_contenu_suspect' => 'テキストのフォーマットが正しくはありません。',
	'erreur_email_deja_existant' => 'このメールアドレスは既に登録されています。',
	'erreur_nom_connect_incorrect' => 'サーバー名は許可されていません。',
	'erreur_plugin_attribut_balise_manquant' => '@balise@タグに@attribut@属性が欠けています。',
	'erreur_plugin_desinstalation_echouee' => 'プラグインのアンインストールが失敗しました。まず、プラグインを無効にしてください。',
	'erreur_plugin_fichier_absent' => 'ファイルが見つかりません。',
	'erreur_plugin_fichier_def_absent' => '定義ファイルが見つかりません。',
	'erreur_plugin_nom_fonction_interdit' => '関数名は不可です。',
	'erreur_plugin_nom_manquant' => 'プラーグイン名が見つかりません。',
	'erreur_plugin_prefix_manquant' => 'このプラグインの命名エリアは未定義です。',
	'erreur_plugin_tag_plugin_absent' => '定義ファイルには「プラーグイン」が見つかりません。',
	'erreur_plugin_version_manquant' => 'プラーグインバーションが欠けています。',

	// H
	'htaccess_a_simuler' => '警告：HTTPサーバー設定は@htaccess@ファイルを無視しています。適切なセキュリティを確保するには、この設定を変更する必要があります。
または、（ファイルmy_options.phpで定義できる）@constantes@は、@document_root@の外にあるフォルダーの値を持たなければなりません。',
	'htaccess_inoperant' => 'htaccessは不作動です。',

	// I
	'ical_info1' => 'このページは、サイトの生活に協力するために、いくつかの方法を示しています。',
	'ical_info2' => '技術的な詳細が欲しい場合、迷わずに、<a href="@spipnet@">SPIPの取扱い書</a>を訪れてください。',
	'ical_info_calendrier' => 'カレンダーを2つ自由に使用できます。1つ目は、公開されたすべての記事を発表するサイトマップです。2つ目は、最近の個人的なメッセージも、出版的な告知も表します。このカレンダーは、（パスワードを更新する時、いつでも変更できる）個人用のキーで表されています。',
	'ical_methode_http' => 'ダウンロードする',
	'ical_methode_webcal' => '(webcal://)同期する',
	'ical_texte_prive' => '厳密に個人的な使用するこのカレンダーは、サイトの個人的な編集活動（個人的なタスクや予定、記事、短いニュース項目など）を通知します。',
	'ical_texte_public' => 'このカレンダーでは、一般的な活動（記事やニュースを公開）を管理することができます。',
	'ical_texte_rss' => 'XML / RSS形式（Rich Site Summary）で、任意のファイルリーダーで、このサイトのニュースを参照できます。また、互換性のある交換フォーマットを使用して、他のサイトに公開されているニュースをSPIPが読むことができるフォーマットです。',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'メーリングリスト',
	'ical_titre_rss' => 'Backendファイル',
	'icone_accueil' => 'ホーム',
	'icone_activer_cookie' => 'クッキーを置く',
	'icone_activite' => '活動',
	'icone_admin_plugin' => 'プラグイン管理',
	'icone_administration' => '整備',
	'icone_afficher_auteurs' => '著者を表示',
	'icone_afficher_visiteurs' => '訪問者を表示',
	'icone_arret_discussion' => '話し合いに参加することを停止する',
	'icone_calendrier' => 'カレンダー',
	'icone_configuration' => '環境設定',
	'icone_creer_auteur' => '新しい著者を作って、彼をこの記事に参加させる。',
	'icone_creer_mot_cle' => '新規キーワードを作成して、記事に関連付ける',
	'icone_creer_rubrique_2' => '新規セクション作成',
	'icone_developpement' => '開発',
	'icone_edition' => '編集',
	'icone_ma_langue' => '私の言語',
	'icone_mes_infos' => '私についての情報',
	'icone_mes_preferences' => '私の環境設定',
	'icone_modifier_article' => '記事を修正する',
	'icone_modifier_rubrique' => 'セクションを修正する',
	'icone_publication' => '公開',
	'icone_relancer_signataire' => '署名者を再開する',
	'icone_retour' => '戻る',
	'icone_retour_article' => '記事に戻る',
	'icone_squelette' => 'テンプレート',
	'icone_suivi_publication' => '公開物のフォローアップ',
	'icone_supprimer_cookie' => 'クッキーを削除する',
	'icone_supprimer_rubrique' => 'セクションを削除する',
	'icone_supprimer_signature' => '署名を削除する',
	'icone_valider_signature' => '署名を確認する',
	'image_administrer_rubrique' => 'あなたはこのセクションを管理することができる',
	'impossible_modifier_login_auteur' => 'ログイン編集不可',
	'impossible_modifier_pass_auteur' => 'パスワード編集不可',
	'info_1_article' => '記事１件',
	'info_1_auteur' => '著者１名',
	'info_1_message' => 'メッセージ１件',
	'info_1_mot_cle' => 'キーワード１つ',
	'info_1_rubrique' => 'セクション１つ',
	'info_1_visiteur' => '訪問者１名',
	'info_activer_cookie' => '<b>管理者用クッキー</b>を有効にすると、公開サイトから管理サイトに簡単に切り替えることが出来ます。',
	'info_activer_menu_developpement' => '開発メニューを表示する',
	'info_admin_etre_webmestre' => 'ウェブマスターのアクセス権を与えてもらう。',
	'info_admin_je_suis_webmestre' => '私は<b>ウェブマスター</b>です。',
	'info_admin_statuer_webmestre' => 'この管理者にウェブマスターのアクセス権を与える。', # MODIF
	'info_admin_webmestre' => 'この管理者は<b>ウェブマスター</b>です。', # MODIF
	'info_administrateur' => '管理者', # MODIF
	'info_administrateur_1' => '管理者', # MODIF
	'info_administrateur_2' => 'サイトについて（<b>注意して使って</b>）',
	'info_administrateur_site_01' => 'サイトの管理者であれば', # MODIF
	'info_administrateur_site_02' => 'このリンクをクリックしてください。',
	'info_administrateurs' => '管理者', # MODIF
	'info_administrer_rubrique' => 'あなたはこのセクションを管理することができる',
	'info_adresse' => 'そのアドレスへ：',
	'info_adresse_desinscription' => '登録解除するには：',
	'info_adresse_url' => '公開サイトのアドレス（URL）：',
	'info_afficher_par_nb' => '番号による表示',
	'info_aide_en_ligne' => 'SPIPオンラインヘルプ',
	'info_ajout_image' => '記事に書類として画像を添付するとき、SPIPが画像のサムネイルを作成します。それで、自動的に写真集などを作成することが出来ます。',
	'info_ajouter_rubrique' => '管理ができるセクションを追加する：',
	'info_annonce_nouveautes' => '最新の告知',
	'info_article' => '記事',
	'info_article_2' => '記事',
	'info_article_a_paraitre' => '公開する後日付けの記事を投稿する',
	'info_articles_02' => '記事',
	'info_articles_2' => '記事',
	'info_articles_auteur' => 'この著者の記事',
	'info_articles_miens' => '私の記事',
	'info_articles_tous' => '全ての記事',
	'info_articles_trouves' => '見つかった記事',
	'info_attente_validation' => '未確認の私の記事',
	'info_aucun_article' => '記事なし',
	'info_aucun_auteur' => '著者なし',
	'info_aucun_message' => 'メッセージなし',
	'info_aucun_rubrique' => 'セクションなし',
	'info_aujourdhui' => '今日：',
	'info_auteur_gere_rubriques' => 'この著者は次のセクションを管理しています：',
	'info_auteur_gere_toutes_rubriques' => 'この著者は<b>全てのセクション</b>を管理しています。',
	'info_auteur_gere_toutes_rubriques_2' => '私は<b>全てのセクション</b>を管理しています。',
	'info_auteurs' => '著者',
	'info_auteurs_par_tri' => '著者@partri@',
	'info_auteurs_trouves' => '見つかった著者',
	'info_authentification_externe' => '外部の認証',
	'info_avertissement' => '警告',
	'info_barre_outils' => 'ツールバーと共に？',
	'info_base_installee' => 'データベースの構造がインストールされています。',
	'info_bio' => '伝記',
	'info_cache_desactive' => 'キャッシュが一時的に無効になっています。',
	'info_chapeau' => '飾り',
	'info_chapeau_2' => '序説：',
	'info_chemin_acces_1' => 'オプション：<b>ディレクトリのアクセス・パス</b>',
	'info_chemin_acces_2' => 'ディレクトリ内（名簿）の情報にアクセス・パスを設定してください。この情報は、ディレクトリに保存されているユーザープロファイルを読み取るために必要です。', # MODIF
	'info_chemin_acces_annuaire' => 'オプション : <b>ディレクトリのアクセス・パス',
	'info_choix_base' => '３番目のステップ：',
	'info_classement_1' => ' @liste@ の外',
	'info_classement_2' => ' @liste@ 外',
	'info_code_acces' => 'アクセスコードを忘れないで下さい！',
	'info_config_suivi' => 'もしもこのアドレスがメーリングリストのものと一致する場合、サイト参加者が登録可能なアドレスを下記に表示することができます。記すべきアドレスは、URL（例えばWeb経由の登録ページなど）、サブジェクトを特定してあるメールアドレス (たとえば: <tt>@adresse_suivi@?subject=subscribe</tt>)がいいでしょう。',
	'info_config_suivi_explication' => 'サイトのメーリングリストに登録したら、公開された記事およびニュース項目に関する告知のメールを受け取ります',
	'info_confirmer_passe' => '新規パスワード確認：',
	'info_conflit_edition_avis_non_sauvegarde' => '注意：次のフィールドは他の場所で変更されました。従って、フィールドへの変更は保存されません。',
	'info_conflit_edition_differences' => '違い：',
	'info_conflit_edition_version_enregistree' => '保存されたバーション：',
	'info_conflit_edition_votre_version' => '私のバーション：',
	'info_connexion_base' => '２番目のステップ：<b>データベースに接続しようとしています。</b>',
	'info_connexion_base_donnee' => '最初のステップ：<b>データベースに接続</b>',
	'info_connexion_ldap_ok' => '<b>LDAP接続が成功しました。</b><p>次のステップに進みます。</p>',
	'info_connexion_mysql' => '最初のステップ：<b>データベースに接続</b>',
	'info_connexion_ok' => '接続が成功しました。',
	'info_contact' => '連絡方法',
	'info_contenu_articles' => '記事の内容',
	'info_contributions' => '貢献',
	'info_creation_paragraphe' => '段落・文節を作るには、空の一行を入れてくだい。',
	'info_creation_rubrique' => '記事を作成する前に、<br/>最低セクションを１つ作成する必要があります。<br/>',
	'info_creation_tables' => '４番目のステップ：<b>データベースのテーブルを作成する</b>',
	'info_creer_base' => '新規データベースを<b>作成</b>する：',
	'info_dans_rubrique' => 'セクション内：',
	'info_date_publication_anterieure' => '前日付の公開：',
	'info_date_referencement' => 'サイトを参照した日付：',
	'info_derniere_etape' => '最後のステップ：終わりました！',
	'info_descriptif' => '記述：',
	'info_desinstaller_plugin' => 'プラグインを無効にして、データを削除します。',
	'info_discussion_cours' => '議論中',
	'info_ecrire_article' => '記事を作成する前に、最低セクションを１つ作らなければなりません。',
	'info_email_envoi' => '送信者のメールアドレス（任意）',
	'info_email_envoi_txt' => 'e-mailを送るのに使っている送り主のe-mailアドレスを入力してください（デフォルトで、受信者のアドレスは送信者のアドレスが入力してあります :',
	'info_email_webmestre' => 'ウェブマスターのメールアドレス（任意）', # MODIF
	'info_envoi_email_automatique' => 'メールの自動送信',
	'info_envoyer_maintenant' => '今送信する',
	'info_etape_suivante' => '次のステップに進む',
	'info_etape_suivante_1' => '次のステップに移ることが出来ます。',
	'info_etape_suivante_2' => '次のステップに移ることが出来ます。',
	'info_exceptions_proxy' => 'プロキシの例外',
	'info_exportation_base' => '@archive@へデータベースを移す。',
	'info_facilite_suivi_activite' => 'サイトの管理を容易にするために、SPIPは、著者のメーリングリストへ「記事の確認と記事の公開」を依頼するメールを送信することができます。一つまたは複数のアドレスをカンマで区切って入力します。', # MODIF
	'info_fichiers_authent' => '認証ファイル「.htpasswd」',
	'info_forums_abo_invites' => 'サイトは購読者用の掲示板を持っています。参加するために、訪問者は公開サイトで、購読するように招かれています。', # MODIF
	'info_gauche_admin_tech' => '<p>技術的な整備のこのページには<b>管理者しかアクセスが出来ません。</b>特別な認証プロセスがあるので、WebサイトへのFTPアクセスが必要です。</p>',
	'info_gauche_auteurs' => 'サイトの全著者が表示されています。管理者は緑のアイコン、編集者は黄色いアイコンで示されています。', # MODIF
	'info_gauche_auteurs_exterieurs' => 'サイトへのアクセス権のない外部の著者は、青いアイコンで示し、削除された著者はゴミ箱のアイコンで示されています。',
	'info_gauche_messagerie' => '内部メールを使用すると、著者間のメッセージを交換したり、リマインダー（個人使用）を保管したりします。管理者は管理エリアのホームページに告知を表示することが出来ます。', # MODIF
	'info_gauche_statistiques_referers' => 'このページは、<b>参照</b>、つまり、当サイトへのリンクを持っているサイトのリス
トを表示しています。このリストは24時間ごとにリセットされます。',
	'info_gauche_visiteurs_enregistres' => 'ここでサイトのパブリックなエリアで登録された訪問者たちを探せるでしょう（寄付による掲示板）。',
	'info_generation_miniatures_images' => '画像のサムネイルの生成',
	'info_gerer_trad_objets' => '@objets@：翻訳リンクを管理する。',
	'info_hebergeur_desactiver_envoi_email' => '若干のホストでは、それらサーバー上から自動的にメールを送ることが出来ません。そういう場合、SPIPの次の機能は実施できません。',
	'info_hier' => '昨日：',
	'info_identification_publique' => '公開ＩＤ…',
	'info_image_process' => 'サムネイルを作る最も良い方法を、対応する写真の上を、クリックして選んでください。',
	'info_image_process2' => '<b>付記</b> 画像が表れなければ、サーバーではソフトが使えるように設定してありません。この機能を使いたい場合、プロバイダの技術サポートに「GD」か「Imagick」拡張をインストールしてもらって下さい。',
	'info_images_auto' => '画像の自動制作',
	'info_informations_personnelles' => '５番目のステップ：<b>個人情報</b>',
	'info_inscription' => '登録された日付：',
	'info_inscription_automatique' => '新規編集者の自動登録', # MODIF
	'info_jeu_caractere' => 'サイトの文字コード',
	'info_jours' => '日',
	'info_laisser_champs_vides' => 'これらのフィールドを空白のままにしておく事が出来ます。）',
	'info_langues' => 'サイトの言語',
	'info_ldap_ok' => 'LDAP認証はインストールされています。',
	'info_lien_hypertexte' => 'リンク：',
	'info_liste_nouveautes_envoyee' => '新らしい公開物のリストが送信されました。',
	'info_liste_redacteurs_connectes' => '接続している編集者のリスト', # MODIF
	'info_login_existant' => 'このＩＤは既に使われています。',
	'info_login_trop_court' => 'ログインＩＤが短すぎます。',
	'info_login_trop_court_car_pluriel' => 'ログインには少なくとも@nb@文字を含める必要があります。',
	'info_logos' => 'ロゴ',
	'info_maximum' => '最大：',
	'info_meme_rubrique' => '同じセクションの中には',
	'info_message_en_redaction' => '編集中のメッセージ',
	'info_message_technique' => '技術的なメッセージ：',
	'info_messagerie_interne' => '内部のメッセージ交換',
	'info_mise_a_niveau_base' => 'SQLデータベースがアップグレードした',
	'info_mise_a_niveau_base_2' => '<b>警告!</b>現在のサイトよりも、インストールされたSPIPのバージョンが古いです。データベースが失われ、サイトはもはや動作しない恐れがあります。<b>SPIPを再インストールしてください。</b>',
	'info_modification_enregistree' => '変更が保存されました。',
	'info_modifier_auteur' => '著者を修正する',
	'info_modifier_rubrique' => 'セクションを修正する',
	'info_modifier_titre' => '@titre@を修正する',
	'info_mon_site_spip' => '私のSPIPサイト',
	'info_moyenne' => '平均：',
	'info_multi_cet_article' => 'この記事の言語：',
	'info_multi_langues_choisies' => 'あなたのサイトのエディターが利用できる言語を下で選んでください。もうすでにあなたのサイト内で（リストの上で）使われている言語は無効に出来ません。', # MODIF
	'info_multi_objets' => '@objets@：言語メニューを有効にする',
	'info_multi_secteurs' => '... ルートにあるセクションだけ有効にしますか？',
	'info_nb_articles' => '記事@nb@件',
	'info_nb_auteurs' => '著者@nb@名',
	'info_nb_messages' => 'メッセージ@nb@件',
	'info_nb_mots_cles' => 'キーワード@nb@つ',
	'info_nb_rubriques' => 'セクション@nb@つ',
	'info_nb_visiteurs' => '訪問者@nb@名',
	'info_nom' => 'お名前',
	'info_nom_destinataire' => '受取人のお名前',
	'info_nom_pas_conforme' => 'HTMLタグは使用できません。',
	'info_nom_site' => 'ＨＰの名前',
	'info_nombre_articles' => '記事@nb_articles@件、',
	'info_nombre_rubriques' => 'セクション@nb_rubriques@件、',
	'info_nombre_sites' => 'サイト@nb_sites@件、',
	'info_non_deplacer' => '移さないでください。',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIPは、サイトの最新の公開物を定期的に送ることができます。',
	'info_non_envoi_liste_nouveautes' => '最新のニュースを送信しません。',
	'info_non_modifiable' => '変更できません',
	'info_non_suppression_mot_cle' => 'このキーワードを削除したくはありません。',
	'info_notes' => '補足',
	'info_nouvel_article' => '新規記事',
	'info_nouvelle_traduction' => '新規翻訳：',
	'info_numero_article' => '記事番号：',
	'info_obligatoire_02' => '［必須］',
	'info_option_accepter_visiteurs' => '公開サイトから、訪問者の登録を受け取る', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => '訪問者の登録を断る', # MODIF
	'info_options_avancees' => '詳細オプション',
	'info_ou' => '又は...',
	'info_page_interdite' => 'ページ禁止',
	'info_par_nom' => '名前によるソート',
	'info_par_nombre_article' => '記事の数によって',
	'info_par_statut' => 'ステータスによるソート',
	'info_par_tri' => '「(@tri@によって)」',
	'info_passe_trop_court' => 'パスワードは短すぎます。',
	'info_passe_trop_court_car_pluriel' => 'パスワードは少なくとも@nb@文字を含める必要があります。',
	'info_passes_identiques' => 'その二つのパスワードは違います。',
	'info_plus_cinq_car' => '６文字以上',
	'info_plus_cinq_car_2' => '(６文字以上)',
	'info_plus_trois_car' => '(４文字以上)',
	'info_popularite' => '人気度： @popularite@； 訪問者： @visites@',
	'info_post_scriptum' => '追伸',
	'info_post_scriptum_2' => '追伸：',
	'info_pour' => 'for',
	'info_preview_texte' => '「提案済み」のステータスがある様々な編集物をプレビューすることが出来、および自分が著者のある記事を見ることができます。この機能は、管理者、編集者、または誰でも利用するのですか？', # MODIF
	'info_procedez_par_etape' => '一方一方して進んでください。',
	'info_procedure_maj_version' => '新しいバージョンのSPIPに順応させるために、データベースをアップグレードするべきです。',
	'info_proxy_ok' => 'プロキシテストの成功。',
	'info_ps' => '追伸',
	'info_publier' => '公開',
	'info_publies' => '公開された私の記事',
	'info_question_accepter_visiteurs' => 'サイトのテンプレートがプライベートエリアに入らないで、訪問者の登録を提案したら、以下のオプションを有効にしてください：', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => '公開サイトより新規著者の登録を受け入れますか。<br/>そうであれば、ご訪問者はフォームを使って自動で登録ができます。管理エリアに入ってご自分の記事を提出します。<br/><div class = "notice">登録プロセスで、ご訪問者は管理エリアに入るためにアクセスコードをもたらすメールを受信します。<br/>プロバイダーによっては、メールの自動送信が無効にされることがあります。 その場合、自動登録は不可能です。</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@が@date_diff@分前に中味を編集しました。',
	'info_racine_site' => 'サイトのルート',
	'info_recharger_page' => 'ちょっとしてからこのページを再読込してください。',
	'info_recherche_auteur_zero' => '「@cherche_auteur@」に関しては何も見つかりませんでした。',
	'info_recommencer' => 'やり直してください。',
	'info_redacteur_1' => '編集者',
	'info_redacteur_2' => '管理エリアへのアクセス権を持ちながら。<b>すすめ</b>',
	'info_redacteurs' => '編集者',
	'info_redaction_en_cours' => '編集中',
	'info_redirection' => 'リダイレクション',
	'info_redirection_activee' => 'リダイレクションは有効にされます。',
	'info_redirection_boucle' => 'この記事を記事自身に向けてリダイレクトしようとしています。',
	'info_redirection_desactivee' => 'リダイレクションは無効にされます。',
	'info_refuses' => '記事は拒絶されました。',
	'info_reglage_ldap' => 'オプション：<b>LDAPインポートの設定</b>',
	'info_renvoi_article' => '<b>リダイレクション</b>この記事はそのページを参照します：',
	'info_reserve_admin' => '管理者しかこのアドレスの変更が出来ません。', # MODIF
	'info_restreindre_rubrique' => '管理はこのセクションに制限されています：',
	'info_resultat_recherche' => '検索結果：',
	'info_rubriques' => 'セクション',
	'info_rubriques_02' => 'セクション',
	'info_rubriques_trouvees' => '見つかったセクション',
	'info_sans_titre' => '無名',
	'info_selection_chemin_acces' => '次にディレクトリのアクセスパスを<b>選択</b>してください。',
	'info_signatures' => '署名',
	'info_site' => 'サイト',
	'info_site_2' => 'サイト：',
	'info_site_min' => 'サイト',
	'info_site_reference_2' => '参照されたサイト',
	'info_site_web' => 'ウェブサイト：',
	'info_sites' => 'サイト',
	'info_sites_lies_mot' => '参照されたサイトをこのキーワードと関連付ける',
	'info_sites_proxy' => 'プロキシ使用',
	'info_sites_trouves' => '見つかったサイト',
	'info_sous_titre' => 'サブタイトル:',
	'info_statut_administrateur' => '管理者です。', # MODIF
	'info_statut_auteur' => '管理者のステータス：',
	'info_statut_auteur_2' => '私は、',
	'info_statut_auteur_a_confirmer' => '確認されるべきの登録',
	'info_statut_auteur_autre' => 'その他のステータス：',
	'info_statut_redacteur' => 'エディターです。',
	'info_statut_utilisateurs_1' => '読み込まれたユーザーの標準のステータス', # MODIF
	'info_statut_utilisateurs_2' => 'LDAPディレクトリ内のユーザーが初めてログインする時には、ユーザー用のステータスを選択してください。その後、各ユーザーのステータスを管理することができます。', # MODIF
	'info_suivi_activite' => '編集活動に従うこと',
	'info_surtitre' => 'トップタイトル：',
	'info_syndication_integrale_1' => '当サイトは参照ファイルを提供します。（「<a href=\\"@url@\\">@titre@</a>」を見てください。）',
	'info_syndication_integrale_2' => '記事全体か、または数百文字の要約のみ送信しますか？',
	'info_table_prefix' => '複数のサイトは同じデータベースを読み込むなら、データベーステーブルの名前の接頭辞を変更する必要があります。（接頭辞は、スペースなし小文字で書いてください。）',
	'info_taille_maximale_images' => 'SPIPは処理ができる画像の最大サイズをテストします。<br/>大きすぎる画像は縮小されません。',
	'info_taille_maximale_vignette' => 'SPIPが処理するサムネイルの最大サイズ：',
	'info_terminer_installation' => 'これで標準インストール手順を完了できます。',
	'info_texte' => 'テキスト',
	'info_texte_explicatif' => '説明用の文章',
	'info_texte_long' => '（文章が長い：いくつかに文章に分けられていますが、確認後、システムが自動で繋ぎます。）',
	'info_texte_message' => 'メッセージの文章：',
	'info_texte_message_02' => 'メッセージの文章：',
	'info_titre' => '題名：',
	'info_total' => '合計：',
	'info_tous_articles_en_redaction' => '編集中の記事',
	'info_tous_articles_presents' => 'このセクションに公開されたすべての記事',
	'info_tous_articles_refuses' => '拒否された記事',
	'info_tous_les' => 'すべて：',
	'info_tout_site' => '全サイト',
	'info_tout_site2' => '記事はこの言語へ翻訳されていません。',
	'info_tout_site3' => '記事はこの言語へ翻訳されましたが、後ほど元の記事が修正されたので、翻訳を更新する必要もあります。',
	'info_tout_site4' => '記事はこの言語へ翻訳されており、翻訳も更新になりました。',
	'info_tout_site5' => '元の記事。',
	'info_tout_site6' => '<b>警告：</b>元の記事のみ表示されています。これに関連付けられる翻訳は、ステータスを示す色で表示されます：',
	'info_traductions' => '翻訳',
	'info_travail_colaboratif' => '記事の共同作業',
	'info_un_article' => '記事１件、',
	'info_un_site' => 'サイト１つ、',
	'info_une_rubrique' => 'セクション１つ、',
	'info_une_rubrique_02' => 'セッション１つ',
	'info_url' => 'URL:',
	'info_url_proxy' => 'プロクシURL',
	'info_url_proxy_pas_conforme' => 'プロクシのURLは無効です。',
	'info_url_site_pas_conforme' => 'サイトのURLは無効です。',
	'info_url_test_proxy' => 'テストのURL',
	'info_urlref' => 'リンク:',
	'info_utilisation_spip' => 'SPIPが使えるようになってきました。',
	'info_visites_par_mois' => '月で表示：',
	'info_visiteur_1' => '訪問者',
	'info_visiteur_2' => '公開サイトの',
	'info_visiteurs' => '訪問者',
	'info_visiteurs_02' => '公開サイトの訪問者数',
	'info_webmestre_forces' => 'ウェブマスターは<b>@file_options@</b>に設定されています。', # MODIF
	'install_adresse_base_hebergeur' => 'データベースURLはプロバイダによって提供されています。',
	'install_connect_ok' => '新しいデータベースは@connect@と名付けられたサーバーとして設定されています。',
	'install_echec_annonce' => 'インストールが失敗する恐れがあって、サイトを作動させられないかもしれません。',
	'install_extension_mbstring' => 'SPIPはこれで作動しません：',
	'install_extension_php_obligatoire' => 'SPIPにはこのphpの拡張モジュールが必要です：',
	'install_login_base_hebergeur' => 'ログインはプロバイダによって提供されています。',
	'install_nom_base_hebergeur' => 'プロバイダによって提供されたデーターベース名は：',
	'install_pas_table' => '現在データーベースのテーブルは設定していません。',
	'install_pass_base_hebergeur' => 'パスワードはプロバイダによって提供されています。',
	'install_php_version' => 'PHPバージョン@version@はあまり古いです。（最低 = @minimum@）',
	'install_select_langue' => '言語を選択し、「次へ」ボタンをクリックすると、インストールが始まります。',
	'install_select_type_db' => 'データベース型を選択してください：',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'データーベース・サーバーはプロバイダによって提供されています。',
	'install_table_prefix_hebergeur' => 'テーブル接頭辞はプロバイダによって提供されています。',
	'install_tables_base' => 'データーベースのテーブル',
	'install_types_db_connus' => 'SPIPは<b>MySQL</b>（最も一般的）と<b>SQLite</b>を使用できます。',
	'install_types_db_connus_avertissement' => '実際<b>PostgreSQL</b>は実験的にサポートされています。',
	'instituer_erreur_statut_a_change' => 'ステータスは既に変更されています。',
	'instituer_erreur_statut_non_autorise' => 'このステータスを選択することができません。',
	'intem_redacteur' => '編集者',
	'intitule_licence' => 'ライセンス',
	'item_accepter_inscriptions' => '登録を受け取る',
	'item_activer_messages_avertissement' => '警告メッセージを有効にする',
	'item_administrateur_2' => '管理者です。', # MODIF
	'item_afficher_calendrier' => 'カレンダー上に表示',
	'item_autoriser_syndication_integrale' => '参照フィードに記事全体を含める',
	'item_choix_administrateurs' => '管理者', # MODIF
	'item_choix_generation_miniature' => '画像のサムネイルを自動製作する',
	'item_choix_non_generation_miniature' => '画像のサムネイルを製作しない',
	'item_choix_redacteurs' => '編集者',
	'item_choix_visiteurs' => '公開サイトの訪問者',
	'item_creer_fichiers_authent' => '.htpasswdファイルを制作する',
	'item_login' => 'ログインＩＤ',
	'item_messagerie_agenda' => 'メッセージングシステムとカレンダーを有効にする',
	'item_mots_cles_association_articles' => '記事に',
	'item_mots_cles_association_rubriques' => 'セクションに',
	'item_mots_cles_association_sites' => '参照か供給（シンジケート）しているサイト',
	'item_non' => 'いいえ',
	'item_non_accepter_inscriptions' => '登録を受け取らない',
	'item_non_activer_messages_avertissement' => '警告メッセージを表示しない',
	'item_non_afficher_calendrier' => 'カレンダー上に表示しない',
	'item_non_autoriser_syndication_integrale' => '要約のみ送信する',
	'item_non_creer_fichiers_authent' => 'これらファイルを制作しません',
	'item_non_messagerie_agenda' => 'メッセージングシステムとカレンダーを無効にする',
	'item_non_publier_articles' => '設定された公開日前に記事を公開しない。',
	'item_nouvel_auteur' => '新規著者',
	'item_nouvelle_rubrique' => '新規セクション',
	'item_oui' => 'はい',
	'item_publier_articles' => '公開日に関係なく、記事を公開する。',
	'item_reponse_article' => '記事に返信する',
	'item_visiteur' => '訪問者',

	// J
	'jour_non_connu_nc' => '未定義',

	// L
	'label_bando_outils' => 'ツールバー',
	'label_bando_outils_afficher' => 'ツールを表示する',
	'label_bando_outils_masquer' => 'ツールを隠す',
	'label_choix_langue' => '言語を選択してください。',
	'label_nom_fichier_connect' => 'サーバー名を記入してください。',
	'label_slogan_site' => 'サイトの標語',
	'label_taille_ecran' => '画面の幅',
	'label_texte_et_icones_navigation' => 'ナビゲーションメニュー',
	'label_texte_et_icones_page' => 'ページ上に表示する',
	'ldap_correspondance' => 'フィールド@champ@を継承する',
	'ldap_correspondance_1' => 'フィールドLDAPを継承する',
	'ldap_correspondance_2' => 'これらの各SPIPフィールドに、対応するLDAPフィールドの名前を入力します。入力したくない場合、空白のままに残し、スペースやコンマで区切って複数のLDAPフィールドを試してください。',
	'lien_ajouter_auteur' => 'この著者を追加する',
	'lien_ajouter_une_rubrique' => 'このセクションを追加する',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'サイトの名前：',
	'lien_rapide_contenu' => '中味に行く',
	'lien_rapide_navigation' => 'ナビゲーションに行く',
	'lien_rapide_recherche' => '検索に行く',
	'lien_retirer_auteur' => '著者を取り外す',
	'lien_retirer_rubrique' => 'セクションを削除する',
	'lien_retirer_tous_auteurs' => '全著者を取り外す',
	'lien_retirer_toutes_rubriques' => '全セクションを削除する',
	'lien_site' => 'サイト',
	'lien_tout_decocher' => '全てのチェックを外す',
	'lien_tout_deplier' => '全て広げる',
	'lien_tout_replier' => '全て畳む',
	'lien_tout_supprimer' => '全て削除する',
	'lien_trier_nom' => '名前でソートする',
	'lien_trier_nombre_articles' => '記事番号でソートする',
	'lien_trier_statut' => 'ステータスでソートする',
	'lien_voir_en_ligne' => 'オンラインで見る:',
	'logo_article' => '記事のロゴ',
	'logo_auteur' => '著者のロゴ',
	'logo_rubrique' => 'セクションのロゴ',
	'logo_site' => 'サイトのロゴ',
	'logo_standard_rubrique' => 'セクション用の標準的なロゴ',
	'logo_survol' => 'オーバーロゴ',

	// M
	'menu_aide_installation_choix_base' => 'データベースの選択する',
	'module_fichier_langue' => '言語ファイル',
	'module_raccourci' => '言語ショートカット',
	'module_texte_affiche' => '表示されたテキスト',
	'module_texte_explicatif' => 'サイトのファイルテンプレートには、言語ショートカットを挿入できます。使いたい言語の翻訳ファイルがあれば、自動的に翻訳されます。',
	'module_texte_traduction' => '「@module@」の言語ファイルは次の言語が使用可能：',
	'mois_non_connu' => '無知',

	// N
	'nouvelle_version_spip' => 'SPIPの@version@は利用可能です。',
	'nouvelle_version_spip_majeure' => '新規SPIPの@version@は利用可能です。',

	// O
	'onglet_contenu' => '中味',
	'onglet_declarer_une_autre_base' => '他のデータベースを設定する',
	'onglet_discuter' => '分かち合う',
	'onglet_interactivite' => '相互関係',
	'onglet_proprietes' => '特徴',
	'onglet_repartition_actuelle' => '現在',
	'onglet_sous_rubriques' => 'サブセクション',

	// P
	'page_pas_proxy' => 'このページはプロキシを経由してはならない。',
	'pas_de_proxy_pour' => '必要ならば、このプロキシが適用しないマシン、またはドメインを設定してください。（例えば：@exemple@-）',
	'phpinfo' => 'PHP設定',
	'plugin_charge_paquet' => 'アーカイファイル@name@を読み込む',
	'plugin_charger' => 'ダウンロード',
	'plugin_erreur_charger' => 'エラー：zipファイル@zip@は読み込めない',
	'plugin_erreur_droit1' => 'フォルダー<code>@dest@</code>へ書き込めない。',
	'plugin_erreur_droit2' => 'このフォルダーのアクセス権を確認してください。必要ならば、フォルダーを作成してください。FTPでファイルをインストールする可能性もあります。',
	'plugin_erreur_zip' => 'pclzipエラー：@status@エラー',
	'plugin_etat_developpement' => '開発中',
	'plugin_etat_experimental' => '実験中',
	'plugin_etat_stable' => '安定の良い',
	'plugin_etat_test' => '試し中',
	'plugin_impossible_activer' => 'プラグイン@plugin@を有効にできませんでした。',
	'plugin_info_automatique1' => 'プラグインの自動インストールを有効にする：',
	'plugin_info_automatique1_lib' => 'イブラリーの自動インストールを有効にする：',
	'plugin_info_automatique2' => 'フォルダー<code>@rep@</code>を作成する；',
	'plugin_info_automatique3' => 'ザーバーがこのフォルダーに書き込むアクセス権を持っていることを確認してくださ
い。',
	'plugin_info_automatique_creer' => 'ウェブサイトのルートに作成してください。',
	'plugin_info_automatique_exemples' => '例：',
	'plugin_info_automatique_ftp' => 'FTPで<b>@rep@</b>フォルダーにプラグインをインストールすることができます。',
	'plugin_info_automatique_lib' => 'プラグインは、<code>lib/</code>フォルダーにファイルを書き込む必要があります。ウェブサイトのルートに、このフォルダーを作成してください。',
	'plugin_info_automatique_liste' => 'プラグインリスト：',
	'plugin_info_automatique_liste_officielle' => '公式のプラグイン',
	'plugin_info_automatique_liste_update' => 'リストを更新する',
	'plugin_info_automatique_ou' => 'または…',
	'plugin_info_automatique_select' => 'SPIPは、以下に選択されたプラグインを<code>@rep@</code>フォルダーにインストールします。プラグインは既に存在されたら、更新されます。',
	'plugin_info_credit' => 'クレジット',
	'plugin_info_erreur_xml' => 'プラグイン申告が正しくありません。',
	'plugin_info_install_ok' => 'インストール済み',
	'plugin_info_necessite' => '必要とするのは：',
	'plugin_info_non_compatible_spip' => 'このプラグインは、現在のSPIPバージョンと互換性がありません。',
	'plugin_info_plugins_dist_1' => '次のプラグインは、@plugins_dist@フォルダーの中にあって、有効にされています。',
	'plugin_info_plugins_dist_2' => '無効にすることができません。',
	'plugin_info_telecharger' => '@url@からダウンロードし、@rep@にインストールする',
	'plugin_info_upgrade_ok' => '更新済み',
	'plugin_librairies_installees' => 'インストールされたライブラリ',
	'plugin_necessite_extension_php' => 'PHP拡張@plugin@のバーション@version@が必要です。',
	'plugin_necessite_extension_php_sans_version' => 'PHP拡張@plugin@が必要です。',
	'plugin_necessite_lib' => 'このプラグインにはライブラリ@lib@が必要です。',
	'plugin_necessite_php' => 'プラグイン@plugin@のバーション@version@が必要です。',
	'plugin_necessite_plugin' => '@plugin@のバーション@version@が必要です。',
	'plugin_necessite_plugin_sans_version' => 'プラグイン@plugin@が必要です',
	'plugin_necessite_spip' => 'SPIPバージョン@バージョン@以上が必要です/',
	'plugin_source' => 'ソース：',
	'plugin_titre_automatique' => '自動インストール',
	'plugin_titre_automatique_ajouter' => 'プラグインを追加する',
	'plugin_titre_installation' => 'プラグイン@plugin@のインストール',
	'plugin_titre_modifier' => '私のプラグイン',
	'plugin_utilise_extension_php' => 'PHP拡張@plugin@は最低@version@のバーションを使用しています。',
	'plugin_utilise_php' => '@plugin@のプラグインのバージョンは@version@でなければなりません。',
	'plugin_utilise_plugin' => '@plugin@のプラグインは最低@version@バージョンが必要です。',
	'plugin_zip_active' => '有効にするように続けてください。',
	'plugin_zip_adresse' => '圧縮されたプラグインファイル、またはプラグインのリストをロードするには、以下のパスを入力します。',
	'plugin_zip_adresse_champ' => 'プラグインまたはリストのパス',
	'plugin_zip_content' => 'zip(@taille@)ファイルには、<code>@rep@</code>フォルダーにインストールができる次のファイルが含まれています',
	'plugin_zip_installe_finie' => '@zip@ファイルがアンパックされて、インストールされました。',
	'plugin_zip_installe_rep_finie' => '@rep@フォルダーに@zip@ファイルがアンパックされて、インストールされました。',
	'plugin_zip_installer' => 'これでインストールできます。',
	'plugin_zip_telecharge' => '@zip@ファイルはロードされました。',
	'plugins_actif_aucun' => '有効にされたプラグインはありません。',
	'plugins_actif_un' => '有効にされたプラグインは1つ',
	'plugins_actifs' => '有効にされたプラグインは@count@つ',
	'plugins_actifs_liste' => '有効',
	'plugins_compte' => 'プラグイン@count@つ',
	'plugins_disponible_un' => '利用可能のプラグインは1つ',
	'plugins_disponibles' => '利用可能のプラグインは1@count@',
	'plugins_erreur' => 'プラグインエラー：@plugins@',
	'plugins_liste' => 'プラグインのリスト',
	'plugins_liste_dist' => 'ロックされたプラグイン',
	'plugins_recents' => '最近のプラグイン',
	'plugins_tous_liste' => '全てのプラグイン',
	'plugins_vue_hierarchie' => 'パス',
	'plugins_vue_liste' => 'リスト',
	'protocole_ldap' => 'プロトコルバージョン：',

	// Q
	'queue_executer_maintenant' => '今すぐ実行する',
	'queue_info_purger' => '全ての保留中のタスクを削除して、定期タスクのリストを再設定するのにリセットすることも出来ます。',
	'queue_nb_jobs_in_queue' => '保留中のタスクは@nb@つあります。',
	'queue_next_job_in_nb_sec' => '次のタスクが@nb@秒後に始まる',
	'queue_no_job_in_queue' => '保留中のタスクなし',
	'queue_one_job_in_queue' => '保留中のタスク1つ',
	'queue_priorite_tache' => '優先',
	'queue_purger_queue' => 'タスクのリストをリセットする',
	'queue_titre' => 'バックグラウンドのタスク',

	// R
	'repertoire_plugins' => 'フォルダー：',
	'required' => '［必須］',

	// S
	'sans_heure' => '時間指定なし',
	'statut_admin_restreint' => '限定のある管理者',
	'statut_webmestre' => 'ウェブマスター',

	// T
	'tache_cron_asap' => 'CRONタスク@function@（できるだけ早く）',
	'tache_cron_secondes' => 'CRONタスク@function@（@nb@秒間ごとに）',
	'taille_cache_image' => 'SPIPが自動的に生成されたイメージ（サムネイル、画像に変換されたタイトル、TeX形式の数式など）は、@dir@フォルダーに@taille@かかります。',
	'taille_cache_moins_de' => 'キャッシュサイズは@octets@未満です。',
	'taille_cache_octets' => 'キャッシュサイズは現在@octets@です。',
	'taille_cache_vide' => 'キャッシュは空です。',
	'taille_repertoire_cache' => '現在のキャッシュサイズ',
	'text_article_propose_publication' => 'この記事は公開のために提出されています。',
	'texte_acces_ldap_anonyme_1' => '次のフィールドは空白のままにすることができます。ただし、一部のLDAPサーバーは匿名アクセスを受け入れません。その場合、名簿内の情報を検索するには、ログインＩＤを指定する必要があります。',
	'texte_admin_effacer_01' => 'このコマンドは、データベースの内容を<b>すべて</b>消去します、管理者や全編集者のアクセス権を含めて。行なった上で、SPIPを再インストールし、新規データベースと最初の管理者アクセス権を再作成する必要があります。', # MODIF
	'texte_adresse_annuaire_1' => 'ディレクトリがウェブサイトと同じコンピュータにインストールされていれば、おそらく「localhost」です。',
	'texte_ajout_auteur' => '次の著者が記事に追加されました：',
	'texte_annuaire_ldap_1' => 'LDAP名簿にアクセスがあれば、SPIPでユーザを自動的にインポートすることができます。', # MODIF
	'texte_article_statut' => '記事のステータス：',
	'texte_article_virtuel' => '仮想記事',
	'texte_article_virtuel_reference' => '<b>仮想記事：</b>SPIPサイト内に記事が参照されているが、ほかのURLへとリダイレクトしているリダイレクションを取り消すには、上のURLを削除して下さい。',
	'texte_aucun_resultat_auteur' => '「@cherche_auteur@」には、検索結果なし',
	'texte_auteur_messagerie' => '接続中の著者は表示されています。その著者とライブメッセージを交換できます。このリストに自分を表示しないようにすると、他のユーザーには隠れます。', # MODIF
	'texte_auteurs' => '著者',
	'texte_choix_base_1' => 'データベースを選択してください：',
	'texte_choix_base_2' => 'SQLサーバーはいくつかのデータベースを含んでいます。',
	'texte_choix_base_3' => 'プロバイダがあなたに割り当てたデータベース１つを選んで下さい。',
	'texte_choix_table_prefix' => 'テーブルの接頭辞：',
	'texte_compte_element' => '@count@ 要素',
	'texte_compte_elements' => '@count@ 要素',
	'texte_conflit_edition_correction' => '2つのバージョンの違いを比べてください。変更をコピーしてやり直すこともできます。',
	'texte_connexion_mysql' => 'プロバイダが提供したデータベースのサーバーの接続コードを調べてください。',
	'texte_contenu_article' => '（記事についての短い説明）',
	'texte_contenu_articles' => 'あなたのサイト用に決めたレイアウトに基づいて、あなたはいくつかの記事の項目を使うか使わないか決めることが出来ます。次のリストの中から使うものを選択してください。',
	'texte_crash_base' => 'もしあなたのデータベースが壊れたら、あなたは自動的に復元に挑戦することが出来ます。',
	'texte_creer_rubrique' => '記事を書き始める前に、セクションを作成しなければなりません。',
	'texte_date_creation_article' => '記事が作成された日時：',
	'texte_date_creation_objet' => '作成された日時：', # on ajoute le ":"
	'texte_date_publication_anterieure' => '公開前の日付:',
	'texte_date_publication_anterieure_nonaffichee' => '公表前の日時を隠す。',
	'texte_date_publication_article' => 'オンラインに公表された日時:',
	'texte_date_publication_objet' => '公表された日時：',
	'texte_definir_comme_traduction_rubrique' => 'このセクションは、そのセクションの翻訳です：',
	'texte_descriptif_rapide' => '短い記述',
	'texte_effacer_base' => 'SPIPデータベースを削除する',
	'texte_effacer_statistiques' => '統計情報を削除する',
	'texte_en_cours_validation' => '確認のために以下の記事とニュースが提出されました。掲示板を通してご意見を述べてください。',
	'texte_enrichir_mise_a_jour' => '「上のショートカット」を使用すると、テキストのレイアウトを充実させることができます。',
	'texte_fichier_authent' => '<p>SPIPは@dossier@フォルダーに特別なファイル.htpasswdと.htpasswd-adminを作成する必要がありますか？</p><p>これらのファイルを使用したら、サイトの他のエリア（外部統計プログラムなど）に作成者や管理者だけへのアクセスが制限されます。</p><p>このようなファイルを必要としなければ、デフォルトである「ファイル作成なし」オプションにしておくことができます。</p>', # MODIF
	'texte_informations_personnelles_1' => 'SPIPはこのサイト用あなたの個人アカウントを作成します。',
	'texte_informations_personnelles_2' => '（注：再インストールの場合、以前のアクセスがまだ有効していたら、',
	'texte_introductif_article' => '（記事の紹介文章）',
	'texte_jeu_caractere' => 'ユニバーサル文字セット<code>utf-8</code>を使用することをお勧めします。これによって、任意の言語でテキストを表示することが可能になります。最新のブラウザーは皆、この文字セットに完全に互換性です。',
	'texte_jeu_caractere_3' => '現在、使用される文字セットは：',
	'texte_jeu_caractere_4' => 'これは現在のデータに対応していない場合（バックアップからデータベースを修復した後に発生する可能性があります）、別の文字セットを指定することも出来ます。設定したください：',
	'texte_login_ldap_1' => '匿名アクセスのために空白のままに残すか、完全なパスを入力します（例えば、「<code>uid=Kantaro, ou=users, dc=my-domain, dc=com</code>」）',
	'texte_login_precaution' => '警告！これはあなたが現在使っているログインＩＤです。注意してこのフォームを使用してください。',
	'texte_messagerie_agenda' => 'メッセージングシステムによって、著者などは管理エリアで直接通信することができます。それにカレンダーにリンクされています。', # MODIF
	'texte_mise_a_niveau_base_1' => 'SPIPファイルを更新されました。データベースをアップグレードする必要もあります。',
	'texte_modifier_article' => '記事を修正する：',
	'texte_multilinguisme' => '複雑なナビゲーションでオブジェクトを複数の言語で管理する場合は、サイトの構成によって、このオブジェクト用の言語選択メニューを追加できます。',
	'texte_multilinguisme_trad' => 'オブジェクト上の異なる翻訳のリンクを管理する機能を有効にすることもできます。',
	'texte_non_compresse' => '<b>未圧縮</b>（サーバーにはこの機能が対応されません。）',
	'texte_nouvelle_version_spip_1' => 'SPIPの新しいバージョンをインストールしました。',
	'texte_nouvelle_version_spip_2' => 'この新しいバージョンでは、通常よりも完全な更新が必要ですウェブマスターは、@connect@ファイルを削除し、インストールを再開して、データベース接続設定を更新してください。<p>（注意：データベース接続設定を忘れてしまった場合、@connect@ファイルを削除する前に、中身を見てください。）</p>',
	'texte_operation_echec' => '前のページに戻って、他のデータベースを選択するか、新規データベースを作成してください。プロバイダーが提供した情報を確認してください。',
	'texte_plus_trois_car' => '３文字以上',
	'texte_plusieurs_articles' => '「@cherche_auteur@」を検索して、数人の著者を見つけました。',
	'texte_port_annuaire' => '（普通、デフォルトの値が適切です。)',
	'texte_presente_plugin' => 'このページには利用可能なプラグインが表示されます。対応するボックスにチェックを入れることを通して、使って欲しいプラグインを有効にしてください。',
	'texte_proposer_publication' => '記事が出来上がったら、<br/>公開にしてもらうために提出してください。',
	'texte_proxy' => '場合によっては（イントラネット、保護されたネットワーク）、リモートサイト（SPIPの取扱い書、照合されたサイトなど）は、<b>HTTPプロキシ</b>を経由してのみアクセスができます。そうであれば、@proxy_en_cours@の形式で、HTTPプロキシのアドレスを指定してください。そうではない場合、このボックスを空白のままに残してください。',
	'texte_publication_articles_post_dates' => '出版用に未来の日付が設定された記事に対するSPIPの対応を決めて下さい。',
	'texte_rappel_selection_champs' => '（忘れずに、このフィルドをきちんと選択してください。）',
	'texte_recalcul_page' => 'もしあなたが１つのページだけリフレッシュしたい場合、公開エリアで« リフレッシュ »ボタンを使った方が良いです。',
	'texte_recuperer_base' => 'データベースを修理する',
	'texte_reference_mais_redirige' => '記事は、SPIPサイトで参照されていますが、別のURLにリダイレクトされています。',
	'texte_requetes_echouent' => '<p>いくつかのSQLクエリが失敗し、明白な原因がない場合、データベース自体の問題が起きた可能性があります。</p><p>SQLサーバには、損傷されたテーブルを修理する機能が入っています。修理を試すことができます。</p><p>失敗だったら、エラーの手がかりを表示するディスプレイのコピーを保管してください。解決しない場合、プロバイダーと連絡してください。</p>',
	'texte_selection_langue_principale' => 'サイトの「主な言語」を選択してください。<br />選択した言語で記事を書く義務はないのですが、「主な言語」を選択すると、<ul><li>公開サイトの日付のデフォルト形式も</li><li>正しくテキストを表す事も</li><li>公開サイトのフォームで使用される言語も</li><li>管理用のエリアに表示される言語も</li></ul>設定します。',
	'texte_sous_titre' => 'サブタイトル',
	'texte_statistiques_visites' => '（黒い線：日曜日・黒い曲線：平均水準）',
	'texte_statut_attente_validation' => '確認の期待中',
	'texte_statut_publies' => '公開中',
	'texte_statut_refuses' => '拒否',
	'texte_suppression_fichiers' => 'これを使うとSPIPのすべてのキャッシュファイルが削除されます。これを許可すると、特にサイトの構造や画像の重要な変更を入力している場合に備えて、すべてのページのリフレッシュを強制します。',
	'texte_sur_titre' => 'トップタイトル',
	'texte_table_ok' => '： このテーブルはオケです。',
	'texte_tentative_recuperation' => '復元を試みる',
	'texte_tenter_reparation' => 'データベースの復元を試みる',
	'texte_test_proxy' => 'このプロキシをテストするには、テストするWebサイトのアドレスをここに入力します。',
	'texte_titre_02' => '件名:',
	'texte_titre_obligatoire' => '［必須］<b>タイトル</b>',
	'texte_travail_article' => '@nom_auteur_modif@はこの記事を@date_diff@分前に編集しました。',
	'texte_travail_collaboratif' => '数人の著者が同じ記事をよく編集する場合、SPIPは、同時に記事の変更を避けるために、「最近開いた記事」を表示する事ができます。このオプションは、不要な警告メッセージを表示しないように、デフォルトでは無効になっています。', # MODIF
	'texte_vide' => '空白にする',
	'texte_vider_cache' => 'キャッシュを空白にする',
	'titre_admin_tech' => '技術的な整備',
	'titre_ajouter_un_auteur' => '著者を追加する',
	'titre_ajouter_un_mot' => 'キーワードを追加する',
	'titre_cadre_afficher_article' => '記事を表示する：',
	'titre_cadre_afficher_traductions' => '次の言語に関する翻訳のステータスを表示する：',
	'titre_cadre_ajouter_auteur' => '著者追加：',
	'titre_cadre_interieur_rubrique' => 'セクションの中に',
	'titre_cadre_numero_auteur' => '著者番号',
	'titre_cadre_numero_objet' => '@objet@番号：',
	'titre_cadre_signature_obligatoire' => '［必須］<b>署名</b>',
	'titre_config_contenu_notifications' => '通知',
	'titre_config_contenu_prive' => '管理エリア内',
	'titre_config_contenu_public' => '公開サイト内',
	'titre_config_fonctions' => 'サイトの設定',
	'titre_config_langage' => '言語設定',
	'titre_configuration' => 'サイトの設定',
	'titre_configurer_preferences' => '個人環境設定',
	'titre_configurer_preferences_menus' => 'メニュー環境設定',
	'titre_conflit_edition' => '編集中の競合',
	'titre_connexion_ldap' => 'オプション：<b>LDAP接続</b>',
	'titre_groupe_mots' => 'キーワードグループ：',
	'titre_identite_site' => 'サイトのアイデンティティ',
	'titre_langue_article' => '記事の言語',
	'titre_langue_rubrique' => 'セクションの言語',
	'titre_langue_trad_article' => '記事の言語と翻訳版',
	'titre_les_articles' => '記事',
	'titre_messagerie_agenda' => 'メッセージ交換とカレンダー',
	'titre_naviguer_dans_le_site' => 'サイト内のナビ',
	'titre_nouvelle_rubrique' => '新規セクション',
	'titre_numero_rubrique' => 'セクション番号：',
	'titre_page_articles_edit' => '@titre@を変更する',
	'titre_page_articles_page' => '記事',
	'titre_page_articles_tous' => '全てのサイト',
	'titre_page_calendrier' => '@annee@年@nom_mois@月・カレンダー',
	'titre_page_config_contenu' => 'サイト環境設定',
	'titre_page_delete_all' => '不可逆的に完全な削除',
	'titre_page_recherche' => '@recherche@に関する検索結果',
	'titre_page_statistiques_referers' => '統計（入ってくるリンク）',
	'titre_page_upgrade' => 'SPIPアップグレード',
	'titre_preference_menus_favoris' => 'お気に入り項目のメニュー',
	'titre_publication_articles_post_dates' => '将来の日付に公開される記事',
	'titre_reparation' => '修理',
	'titre_suivi_petition' => '誓願書管理',
	'tls_ldap' => 'トランスポート層のセキュリティ：',
	'trad_article_traduction' => 'それぞれの翻訳',
	'trad_delier' => 'この記事をその翻訳に関連付けないで下さい。',
	'trad_lier' => '翻訳に関する、記事の番号は：',
	'trad_new' => '記事の新規翻訳を書く',

	// U
	'utf8_convert_erreur_orig' => 'エラー：その文字セット@charset@は、対応されません。',

	// V
	'version' => 'バージョン:',
];
